@@ -5,7 +5,7 @@ use strict;
 use Class::Autouse qw{Carp Locale::Language Locale::Object::Country Locale::Object::DB I18N::AcceptLanguage I18N::LangTags::Detect Storable};
 
 use vars qw($VERSION);
-our $VERSION = '0.53';
+our $VERSION = '0.54';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ CGI::Lingua - Create a multilingual web page
 
 =head1 VERSION
 
-Version 0.53
+Version 0.54
 
 =cut
 
@@ -726,6 +726,10 @@ caching capability of CGI::Lingua.
 sub country {
 	my $self = shift;
 
+	if($self->{_logger}) {
+		$self->{_logger}->trace('Entered country');
+	}
+
 	# FIXME: If previous calls to country() return undef, we'll
 	# waste time going through again and no doubt returning undef
 	# again.
@@ -753,9 +757,9 @@ sub country {
 		$self->{_country} = $self->{_cache}->get($ip);
 		if($self->{_logger}) {
 			if(defined($self->{_country})) {
-				$self->{_logger}->trace("Get $ip from cache = $self->{_country}");
+				$self->{_logger}->debug("Get $ip from cache = $self->{_country}");
 			} else {
-				$self->{_logger}->trace("$ip isn't in the cache");
+				$self->{_logger}->debug("$ip isn't in the cache");
 			}
 		}
 		if(defined($self->{_country})) {
@@ -777,6 +781,12 @@ sub country {
 			return;
 		}
 	}
+	if(is_private_ipv4($ip)) {
+		if($self->{_logger}) {
+			$self->{_logger}->trace("Can't determine country from LAN connection $ip");
+		}
+		return;
+	}
 
 	if($self->{_have_ipcountry} == -1) {
 		if(eval { require IP::Country; }) {
@@ -803,12 +813,16 @@ sub country {
 	}
 	unless(defined($self->{_country})) {
 		if($self->{_have_geoip} == -1) {
-			if(eval { require Geo::IP; }) {
-				Geo::IP->import();
-				$self->{_have_geoip} = 1;
-				# GEOIP_STANDARD = 0, can't use that because you'll
-				# get a syntax error
-				$self->{_geoip} = Geo::IP->new(0);
+			if(($^O eq 'MSWin32') || (-r '/usr/local/share/GeoIP/GeoIP.dat')) {
+				if(eval { require Geo::IP; }) {
+					Geo::IP->import();
+					$self->{_have_geoip} = 1;
+					# GEOIP_STANDARD = 0, can't use that because you'll
+					# get a syntax error
+					$self->{_geoip} = Geo::IP->new(0);
+				} else {
+					$self->{_have_geoip} = 0;
+				}
 			} else {
 				$self->{_have_geoip} = 0;
 			}
@@ -886,7 +900,7 @@ sub country {
 			# Hong Kong is no longer a country, but Whois thinks
 			# it is - try "whois 218.213.130.87"
 			$self->{_country} = 'cn';
-		} elsif($self->country eq 'eu') {
+		} elsif($self->{_country} eq 'eu') {
 			require Net::Subnet;
 
 			# RT-86809, Baidu claims it's in EU not CN
